/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useState } from 'react'

import AcessibilityBar from './AcessibilityBar'
import MenuBar from './MenuBar'
import SearchBar from './SearchBar'
import SignUpModal from './SignUpModal'
import LoginModal from './LoginModal.js'
import { Store } from '../Store';
import ColaborarModal from './ColaborarModal.js'
import Snackbar from '@material-ui/core/Snackbar';
import MuiAlert from '@material-ui/lab/Alert';
import {useLocation} from 'react-router-dom'
import MenuBarMobile from './MenuBarMobile.js'

//const StyledButton = styled(Button)`
//    background : #ffa54c !important;
//    boxShadow :none;
//`
function Alert(props) {
  return <MuiAlert elevation={6} variant="filled" {...props} />;
}


export default function Header(props){
  const { state, dispatch } = useContext(Store)
  const [signUpOpen, setSignUp] = useState(false)
  const [loginOpen, setLogin] = useState(false)
  const [successfulLoginOpen, handleSuccessfulLogin] = useState(false)
  const [modalColaborar, setModalColaborar] = useState(false)

  const toggleSnackbar = (event, reason) => {
      if (reason === 'clickaway') {
          return;
      }

      handleSuccessfulLogin(false);
  }

  const handleSignUp = () => {
      setSignUp(!signUpOpen)
  }

  const handleLogin = () => {
      setLogin(!loginOpen)
  }

  const handleClickSearch = (open) => {
    dispatch({
      type: "HANDLE_SEARCH_BAR",
      opened: !state.searchOpen
    })
  }

  let windowWidth = window.innerWidth

  return (
    <React.Fragment>
       {
           windowWidth > 990 &&
           <AcessibilityBar/>
       }
        <Snackbar open={successfulLoginOpen} autoHideDuration={1000} onClose={toggleSnackbar}
                  anchorOrigin = {{ vertical:'top', horizontal:'center' }}
              >
              <Alert severity="success" style={{backgroundColor:"#00acc1"}}>Você está conectado(a)!</Alert>
        </Snackbar>
        {
            windowWidth > 990 ?
            (
                <React.Fragment>
                    <MenuBar openSearchBar={handleClickSearch} openSignUp = {handleSignUp} openLogin = {handleLogin}/>
                    {
                    state.searchOpen &&
                    <SearchBar/>
                    }
                </React.Fragment>

            )
            :
            (
                <MenuBarMobile openSignUp = {handleSignUp} openLogin = {handleLogin}/>
            )
        }
      <SignUpModal open={signUpOpen} handleClose={handleSignUp} openLogin={handleLogin}/>
      <LoginModal open={loginOpen} handleClose={() => setLogin(false)}      openSignUp={handleSignUp}
                  openSnackbar={() => {handleSuccessfulLogin(true)}}/>
      <ColaborarModal open={modalColaborar} handleClose={() => {setModalColaborar(!modalColaborar)}} />
    </React.Fragment>
  )
}
