/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useContext} from 'react'
import {Store} from '../../Store.js'
import styled from 'styled-components'
import Grid from '@material-ui/core/Grid';
import { Button } from '@material-ui/core';
import ErrorIcon from '@material-ui/icons/Error';
import ShareIcon from '@material-ui/icons/Share';
import FolderIcon from '@material-ui/icons/Folder';
import GetAppIcon from '@material-ui/icons/GetApp';
import CallMadeIcon from '@material-ui/icons/CallMade';
import {Link} from 'react-router-dom'
import ReportModal from '../ReportModal.js'
import ReportRecursoForm from '../ReportRecursoForm.js'
import ShareModal from '../ShareModal.js'
import GuardarModal from '../GuardarModal.js'
import RedirectModal from '../RedirectModal'
import MoreVertIcon from '@material-ui/icons/MoreVert';
import Menu from '@material-ui/core/Menu';
import MenuItem from '@material-ui/core/MenuItem';

function ReportButton (props) {
    return (
            !props.complained ?
            (
                <ButtonGrey onClick={props.userLoggedIn ? props.toggleReport : props.openLogin}>
                    <span className="button-text">
                        <ErrorIcon className="icon"/> Reportar abuso ou erro
                    </span>
                </ButtonGrey>
            )
            :
            (
                <ButtonGrey>
                    <span className="button-text-report">
                        <ErrorIcon className="icon"/> Você já reportou este recurso
                    </span>
                </ButtonGrey>
            )
    )
}

function DownloadButton (props) {
    return (
            props.downloadableLink ?
            (
                    <ButtonOrange onClick={props.enableDownload}>
                        <span className="text">
                            <GetAppIcon className="icon"/> Baixar Recurso
                            </span>
                        </ButtonOrange>
            )
            :
                props.link ?
                (
                        <ButtonOrange onClick={props.toggleRedirect}>
                            <span className="text">
                                <CallMadeIcon className="icon"/> Abrir Recurso
                                </span>
                            </ButtonOrange>
                )
                :
                (
                    <React.Fragment/>
                )
    )
}

export default function Footer (props) {
    const {state} = useContext(Store)
    const enableDownload = () => {
        const url = props.downloadableLink
        window.open(url, '_blank');
        props.handleSnackbar(0)
    }
    let windowWidth = window.innerWidth
    const [reportOpen, toggleReport] = useState(false)
    const [shareOpen, toggleShare] = useState(false)
    const [saveToCol, toggleSave] = useState(false)
    const [redirectOpen, toggleRedirect] = useState(false)

    const [anchorEl, setAnchorEl] = React.useState(null);

    function handleClick(event) {
      setAnchorEl(event.currentTarget);
    }

    function handleClose() {
      setAnchorEl(null);
    }

    return (
        <React.Fragment>
            {/*-------------------------------MODALS---------------------------------------*/}
            <ReportModal open={reportOpen} handleClose={() => {toggleReport(false)}}
                form="recurso"
                complainableId={props.recursoId}
                complainableType={"LearningObject"}
                />
            <ShareModal open={shareOpen} handleClose={() => {toggleShare(false)}}
                thumb={props.thumb} title={props.title} link={props.currPageLink}
                />

            <GuardarModal open={saveToCol} handleClose={() => {toggleSave(false)}}
                thumb={props.thumb} title={props.title} recursoId={props.recursoId}
                />
            <RedirectModal open={redirectOpen} handleClose={() => {toggleRedirect(false)}}
                link={props.link}
                />
            {/*----------------------------------------------------------------------------*/}

            {/*-----------------------------BUTTONS----------------------------------------*/}
            <OpcoesDiv>
                <StyledGrid container>
                    {
                        windowWidth > 990 ?
                        (
                            <React.Fragment>
                            {/*Botao Reportar*/}
                            <Grid item xs={3}>
                                <ReportButton
                                    userLoggedIn={state.currentUser.id === '' ? false : true}
                                    toggleReport={() => {toggleReport(true)}}
                                    openLogin={() => console.log('abrir login modal')}
                                    complained={props.complained}
                                    />
                            </Grid>

                            {/*Botao Compartilhar*/}
                            <Grid item xs={3}>
                                <ButtonGrey onClick={state.currentUser.id === '' ? () => console.log('abrir login modal') : () => toggleShare(true)}>
                                    <span className="button-text">
                                        <ShareIcon className="icon"/> Compartilhar
                                    </span>
                                </ButtonGrey>
                            </Grid>

                            {/*Botao Guardar*/}
                            <Grid item xs={3}>
                                <ButtonGrey onClick={state.currentUser.id === '' ? () => console.log('abrir login modal') : () => toggleSave(true)}>
                                    <span className="button-text">
                                        <FolderIcon className="icon"/>Guardar
                                    </span>
                                </ButtonGrey>
                            </Grid>

                            <Grid item xs={3} style={{justifyContent : "right !important"}}>
                                <DownloadButton
                                    downloadableLink={props.downloadableLink}
                                    link={props.link}
                                    enableDownload={enableDownload}
                                    toggleRedirect={() => {toggleRedirect(true)}}
                                    />
                            </Grid>
                            </React.Fragment>
                        )
                        :
                        (
                            <React.Fragment>
                            {/*Botao Guardar*/}
                            <Grid item xs={4}>
                                <ButtonGrey onClick={state.currentUser.id === '' ? () => console.log('abrir login modal') : () => toggleSave(true)}>
                                    <span className="button-text">
                                        <FolderIcon className="icon"/>Guardar
                                    </span>
                                </ButtonGrey>
                            </Grid>

                            <Grid item xs={7}>
                            <DownloadButton
                                downloadableLink={props.downloadableLink}
                                link={props.link}
                                enableDownload={enableDownload}
                                toggleRedirect={() => {toggleRedirect(true)}}
                                />
                            </Grid>

                            <Grid item xs={1}>
                                <Button aria-haspopup="true" onClick={handleClick} style={{color : "#666"}}>
                                    <MoreVertIcon/>
                                </Button>
                                <Menu
                                  id="simple-menu"
                                  anchorEl={anchorEl}
                                  keepMounted
                                  open={Boolean(anchorEl)}
                                  onClose={handleClose}
                                >
                                    <MenuItem>
                                        <ReportButton
                                            userLoggedIn={state.currentUser.id === '' ? false : true}
                                            toggleReport={() => {toggleReport(true)}}
                                            openLogin={() => console.log('abrir login modal')}
                                            complained={props.complained}
                                            />
                                    </MenuItem>
                                    <MenuItem>
                                        <ButtonGrey onClick={state.currentUser.id === '' ? () => console.log('abrir login modal') : () => toggleShare(true)}>
                                            <span className="button-text">
                                                <ShareIcon className="icon"/> Compartilhar
                                            </span>
                                        </ButtonGrey>
                                    </MenuItem>
                                </Menu>
                            </Grid>
                            </React.Fragment>
                        )
                    }


                </StyledGrid>
            </OpcoesDiv>
        </React.Fragment>
    )
}

const OpcoesDiv = styled.div`
    display : flex;
    align-items : center;
    height : 65px;
    background-color : #fafafa;
`

const StyledGrid = styled(Grid)`
    @media screen and (min-width: 990px) {
        padding-left : 15px !important;
    }

    .MuiGrid-item {
        padding-right : 15px;
        padding-left : 15px;
        display : flex;
        justify-content : center;
    }
`

const ButtonGrey = styled(Button)`
    &:hover {
        background-color : rgba(158,158,158,0.2) !important;
    }
    background-color : transparent !important;
    color : #666 !important;
    text-decoration : none !important;
    outline : none !important;
    text-align : center !important;

    .icon {
        vertical-align : middle !important;
        font-weight : normal !important;
        font-style : normal !important;
        font-size : 24px !important;
        line-height : 1 !important;
        letter-spacing : normal !important;
        text-transform : none !important;
        display : inline-block !important;
        white-space : nowrap !important;
        word-wrap : normal !important;
        direction : ltr !important;
        padding-right : 2px;
        color : inherit !important;
    }

    .button-text {
        cursor : pointer;
        line-height : 36px;
        text-align : center;
        color : currentColor;
        white-space : nowrap;
        text-transform : uppercase;
        font-weight : 600;
        font-size : 14px;
        font-style : inherit;
        font-variant : inherit;
    }
    .button-text-report {
        cursor : pointer;
        line-height : 36px;
        text-align : center;
        color : red !important;
        white-space : nowrap;
        text-transform : uppercase;
        font-weight : 600;
        font-size : 14px;
        font-style : inherit;
        font-variant : inherit;
    }
`

const ButtonOrange = styled(Button)`
    box-shadow : 0 2px 5px 0 rgba(0,0,0,.26) !important;
    background-color : #ff7f00 !important;
    color : #fff !important;
    text-decoration : none !important;
    text-transform : uppercase !important;
    outline : none !important;
    text-align : center !important;
    max-height : 36px;
    margin-top : 5px !important;

    .icon {
        vertical-align : middle !important;
        font-weight : normal !important;
        font-style : normal !important;
        font-size : 24px !important;
        line-height : 1 !important;
        letter-spacing : normal !important;
        text-transform : none !important;
        display : inline-block !important;
        white-space : nowrap !important;
        word-wrap : normal !important;
        direction : ltr !important;
        padding-right : 2px;
    }

    .text {
        font-size : 14px;
        font-weight : 600;
    }
`
