/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext, useState, useEffect} from 'react'
import axios from 'axios'
import {apiUrl, apiDomain} from '../../../env';
import LoadingSpinner from '../../LoadingSpinner.js'
import ContainerRedeVazia from './ContainerRedeVazia.js'
import PanelTemplateRede from '../PanelComponents/TemplateRede.js'

export default function TabPanelRede (props) {
    const [loading, handleLoading] = useState(true)

    const [followingList, setFollowing] = useState([])
    const [followingSlice, setFollowingSlice] = useState([])

    const [followersList, setFollowers] = useState([])
    const [followersSlice, setFollowersSlice] = useState([])

    const showMoreFollowing = () => {
        var sliceLength = followingSlice.length
        setFollowingSlice(followingList.slice(0, sliceLength + 4))
    }
    const showAllFollowing = () => {setFollowingSlice(followingList)}

        const showMoreFollowers = () => {
        var sliceLength = followersSlice.length
        setFollowersSlice(followersList.slice(0, sliceLength + 4))
    }
    const showAllFollowers = () => {setFollowersSlice(followersList)}


    useEffect( () => {
        axios.all([
            axios.get((`${apiUrl}/users/` + props.id + '/following/User'), props.config),
            axios.get((`${apiUrl}/users/` + props.id + '/followers'), props.config)
        ])
        .then( (responseArr) => {
                console.log('responseArr Rede: ', responseArr)
                if (responseArr[0].headers['access-token']) {
                    sessionStorage.setItem('@portalmec/accessToken', responseArr[0].headers['access-token'])
                }

                setFollowing(responseArr[0].data)
                setFollowingSlice(responseArr[0].data.slice(0,4))


                setFollowers(responseArr[1].data)
                setFollowersSlice(responseArr[1].data.slice(0,4))

                handleLoading(false)
            },
            (error) => {
                handleLoading(false)
                console.log('error while running axios all')
            }
        )
    }, [])

    return (
        <>
        {
            loading ?
            (
                [
                    <LoadingSpinner text={'CARREGANDO...'}/>
                ]
            )
            :
            (
                [
                    <>
                    {
                        followingList.length == 0 && followersList.length == 0 ?
                        (
                            [
                                <>
                                    <ContainerRedeVazia/>
                                </>
                            ]
                        )
                        :
                        (
                            [
                                <React.Fragment>
                                    <PanelTemplateRede
                                        title={followersList.length == 1 ? "Seguidor" : "Seguidores"}
                                        length={followersList.length}
                                        sliceArr={followersSlice}
                                        showMore={showMoreFollowers}
                                        showAll={showAllFollowers}
                                        follower={true}
                                        noContentText={'Você não possui nenhum seguidor'}
                                    />

                                <PanelTemplateRede
                                        title={"Seguindo"}
                                        length={followingList.length}
                                        sliceArr={followingSlice}
                                        showMore={showMoreFollowing}
                                        showAll={showAllFollowing}
                                        follower={false}
                                        noContentText={'Você ainda não segue nenhum usuário'}
                                    />
                                </React.Fragment>

                            ]
                        )
                    }
                    </>
                ]
            )
        }
        </>
    )
}
