/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, memo, useContext} from 'react'
import {Store} from '../../../Store.js'
import { withStyles } from '@material-ui/core/styles';

import FormControl from '@material-ui/core/FormControl';
import {StyledTextField, StyledFormLabel, OutroAutorTextField} from '../StyledComponents.js'
import FormHelperText from '@material-ui/core/FormHelperText';
import RadioGroup from '@material-ui/core/RadioGroup';
import Radio from '@material-ui/core/Radio';
import FormControlLabel from '@material-ui/core/FormControlLabel';

const BlueRadio = withStyles({
  root: {
    color: '#666',
    '&$checked': {
      color: '#00bcd4',
    },
  },
  checked: {},
})((props) => <Radio color="default" {...props} />);

function Autor (props) {
    const {state} = useContext(Store)
    const [authorValue, setAuthorValue] = useState(props.initialValue ? props.initialValue : -1)
    const [outroAutor, setOutroAutor] = useState(props.initialOutroAutor ? props.initialOutroAutor : '')

    const getAuthor = () => {
        return authorValue === "0" ? state.currentUser.username : outroAutor
    }

    return (
        <FormControl required={true} style={{width : "100%"}} onBlur={() => {props.onBlurCallback("author", getAuthor(), props.draftID)}}>
            <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                <b>Autor do recurso</b>
            </StyledFormLabel>
            <RadioGroup ara-label="Autor do Recurso" name="Autor do Recurso" value={authorValue} onChange={(e) => {setAuthorValue(e.target.value)}}>
                 <FormControlLabel value="0" control={<BlueRadio />} label="Sou o(a) autor(a) deste recurso"/>
                 <FormControlLabel value="1" control={<BlueRadio/>}
                     label={
                         <div style={{display : "flex", alignItems : "center"}}>
                             Outro:
                             <OutroAutorTextField
                                 id = {"outro-autor-form"}
                                 placeholder={"Nome dos autores"}
                                 type = {"text"}
                                 value = {outroAutor}
                                 onChange = {e => {setOutroAutor(e.target.value)}}
                                 disabled = {authorValue === "0"}
                                 style={{paddingLeft : "5px", width : "100%"}}
                            />
                        </div>}
                />
             </RadioGroup>
        </FormControl>
    )
}

export default memo(Autor)
