/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, memo, useEffect} from 'react'
import FormControl from '@material-ui/core/FormControl';
import {StyledTextField, StyledFormLabel} from '../StyledComponents.js'
import FormHelperText from '@material-ui/core/FormHelperText';
import Chip from '@material-ui/core/Chip';

function Keywords (props) {

    const [keywords, setKeywords] = useState(props.initialValue ? props.initialValue : [])
    const handleSetKeywords = (newKeyword) => {setKeywords(newKeyword)}
    const deleteKeyword = (keywordToDelete) => {
        setKeywords(keywords.filter((keyword) => keyword !== keywordToDelete))
    }

    const [keywordsBuffer, setKeywordsBuffer] = useState('')

    const handleKeywords = (event) => {
        let userInput = event.target.value;

        if(userInput.indexOf(',') != -1 ) {
            if(userInput.length > 1) {
                handleSetKeywords([...keywords, userInput.split(',')[0]])
            }
            setKeywordsBuffer('')
        }
        else {
            setKeywordsBuffer(userInput)
        }
    }


    return (
        <React.Fragment>
            <FormControl required={true} style={{width : "100%"}}>
                <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                    <b>Palavras-chave para buscar o Recurso</b>
                    <span style={{color : "#a5a5a5", paddingLeft : "10px"}}>
                    (Use vírgula ou enter para separar as palavras-chave)</span>
                </StyledFormLabel>
                <StyledTextField
                    id = {"text-form"}
                    placeholder={"Ex: Biomas, Geografia, ..."}
                    type = {"text"}
                    value={keywordsBuffer}
                    onChange={handleKeywords}
                    onKeyDown={(event) => {
                        if(event.keyCode === 13){
                            handleSetKeywords([...keywords, keywordsBuffer])
                            setKeywordsBuffer('')}}
                        }
                    fullWidth
                    onBlur={() => {props.onBlurCallback("tags", keywords, props.draftID)}}
                />
            </FormControl>
            {
                keywords.length !== 0 &&
                <FormHelperText>
                    {
                        keywords.map( (keyword) =>
                            <Chip label={keyword} key={keyword} onDelete={() => deleteKeyword(keyword)} />
                        )
                    }
                </FormHelperText>
            }
        </React.Fragment>
    )
}

export default memo(Keywords)
