/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect, memo} from 'react'
import { makeStyles } from '@material-ui/core/styles';
import FormControl from '@material-ui/core/FormControl';
import {ObjTypeBox, StyledFormLabel} from '../StyledComponents.js'
import FormGroup from '@material-ui/core/FormGroup';
import {GetSubjectIconByName} from '../GetIconByName.js'
import FormControlLabel from '@material-ui/core/FormControlLabel';
import axios from 'axios'
import {apiUrl, apiDomain} from '../../../env';
import Checkbox from '@material-ui/core/Checkbox';
import Grid from '@material-ui/core/Grid';

const useStyles = makeStyles({
  root: {
    '&:hover': {
      backgroundColor: 'transparent',
    },
}})

function StyledCheckbox (props) {
    const classes = useStyles();
    return (
        <Checkbox
            className={classes.root}
            disableRipple
            checkedIcon = {
                <ObjTypeBox checked>
                    <span>
                        {GetSubjectIconByName(props.label)}
                        <p>{props.label}</p>
                    </span>
                </ObjTypeBox>
            }
            icon = {
                <ObjTypeBox>
                    <span>
                        {GetSubjectIconByName(props.label)}
                        <p>{props.label}</p>
                    </span>
                </ObjTypeBox>
            }
            {...props}
        />
    )
}


function SubjectsAndThemes (props) {
    const [value, setValue] = useState(props.initialValue ? props.initialValue : [])

    const handleChange = (event) => {
        const newValue = event.target.value

        if((value.indexOf(newValue) > -1)) {
            setValue(value.filter(item => item !== newValue))
        }
        else {
            setValue(value => [...value, newValue])
        }
     }

    return (
        <React.Fragment>
        <Grid item xs={12} style={{paddingBottom : "40px"}}>
            <FormControl required style={{width : "100%"}}>
                <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                    <b>Componente curricular</b> <span>(Selecione uma ou mais opções)</span>
                </StyledFormLabel>
                <FormGroup row style={{justifyContent : "center"}} onBlur={() => {props.onBlurCallback("subjects", value, props.draftID)}}>
                    {
                        props.subjects.map( (subject) =>
                        <>
                        <FormControlLabel key={subject.id} value={subject.id}
                            control={
                                <StyledCheckbox
                                    label={subject.name}
                                    checked={value.indexOf(String(subject.id)) > -1}
                                    onChange={handleChange}
                                    />}
                            />
                        </>
                        )

                    }
                </FormGroup>
            </FormControl>
        </Grid>

        {

        props.onUploadPage &&
        <Grid item xs={12} style={{paddingBottom : "40px"}}>
            <FormControl style={{width : "100%"}}>
                <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                    <b>Outras Temáticas</b>
                </StyledFormLabel>
                <FormGroup aria-label="Tipo de Recurso" name="Tipo de Recurso" row style={{justifyContent : "center"}} onBlur={() => {props.onBlurCallback("subjects", value, props.draftID)}}>
                    {
                        props.themes.map( (theme) =>
                        <FormControlLabel key={theme.id} value={theme.id}
                            control={
                                <StyledCheckbox
                                    label={theme.name}
                                    checked={value.indexOf(String(theme.id)) > -1}
                                    onChange={handleChange}

                                    />
                            }
                            />
                        )

                    }
                </FormGroup>
            </FormControl>
        </Grid>
        }
        </React.Fragment>
    )
}

export default memo(SubjectsAndThemes)
