/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react'
import CloudUploadIcon from '@material-ui/icons/CloudUpload';
import {DottedBox, BlueButton} from './StyledComponents.js';
import {getAxiosConfig} from '../HelperFunctions/getAxiosConfig.js'
import AddAPhotoIcon from '@material-ui/icons/AddAPhoto';
import axios from 'axios'
import {apiUrl} from '../../env';

export default function ReactFileToUpload (props) {
    const [fileToUpload, setFileToUpload] = useState(null); 
    const chunkSize = 262144
    const uploadUrl = `${apiUrl}/learning_objects/` + props.draftID + '/chunk'
    const [fileName, setFileName] = useState(null)
    const [fileSize, setFileSize] = useState(null)
    const [fileDoneUploading, setFileDoneUploading] = useState(false)

    async function onFileChange (e) {
        const files = e.target.files;
        if(!files) return;

        let newFile = e.target.files[0]
        console.log(newFile)
        setFileToUpload(newFile);
        setFileName(newFile.name)
        setFileSize(newFile.size)

        let total = Math.ceil(newFile.size/chunkSize)
        let currentChunkStartByte = 0;
        let currentChunkFinalByte = chunkSize > newFile.size ? newFile.size : chunkSize;
        let chunkIdentifier = props.draftID + '-' + newFile.name;
        let remainingBytes = 0

        for (var i = 0; i < total; i++) {
            let chunk = newFile.slice(currentChunkStartByte, currentChunkFinalByte)
            let config = getAxiosConfig()
            let formData = new FormData()
            formData.append('_chunkFilename', newFile.name);
            formData.append('_chunkIdentifier', chunkIdentifier);
            formData.append('_totalChunks', total);
            formData.append('_chunkSize', chunkSize);
            formData.append('_currentChunkSize', chunk.size);
            formData.append('_chunkNumber', i);
            formData.append('_totalSize', newFile.size);
            formData.append('file', chunk);

            try {
                const response = await axios.post(uploadUrl, formData, config);
                console.log(response)
                if (response.headers['access-token']) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                remainingBytes = newFile.size - currentChunkFinalByte;
                if (currentChunkFinalByte === newFile.size) {
                    setFileDoneUploading(true)
                }
                else if (remainingBytes < chunkSize) {
                    currentChunkStartByte = currentChunkFinalByte;
                    currentChunkFinalByte = currentChunkStartByte + remainingBytes;
                }
                else {
                    currentChunkStartByte = currentChunkFinalByte;
                    currentChunkFinalByte = currentChunkStartByte + chunkSize;
                }
            } catch (error) {
                console.log(error)
            }
        }
    };

    return (
        <div className="upload-container">
            <h2 className="upload-title">File Uploader</h2>
            <div className="upload-form">
                <form id="file_upload">
                    <DottedBox
                        >
                        <AddAPhotoIcon className="icon"/>
                        <input
                            type="file"
                            onChange = {onFileChange}
                            id="upload-file-thumbnail"
                            style={{display : "none"}}
                            />
                        <BlueButton>
                            <label htmlFor="upload-file-thumbnail" style={{width : "inherit", cursor : "pointer"}}>
                                ESCOLHER IMAGEM
                            </label>
                        </BlueButton>
                        <span style={{marginTop : "6px"}}>Ou arrastar e soltar o arquivo aqui</span>
                    </DottedBox>
                </form>
            </div>
        </div>
    )
}
