/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState} from 'react'
import LinkIcon from '../../img/link_icon.svg'
import ChooseLink from './ChooseLinkSection.js'
import {WrapperBox, StyledTextField, BlueButton, GrayButton} from './StyledComponents.js';
import UploadMediaComponent from './ReactFileToUpload.js'
import FileUploadStage from './FileUploadStage.js'
import CloudUploadIcon from '@material-ui/icons/CloudUpload';
import {DottedBox} from './StyledComponents.js';
import {getAxiosConfig} from '../HelperFunctions/getAxiosConfig.js'
import AddAPhotoIcon from '@material-ui/icons/AddAPhoto';
import axios from 'axios'
import {apiUrl} from '../../env';
import DoneIcon from '@material-ui/icons/Done';
import DeleteIcon from '@material-ui/icons/Delete';
import LinearProgress from '@material-ui/core/LinearProgress';
import Alert from '../Alert.js';
import Snackbar from '@material-ui/core/Snackbar';

export default function UploadFileWrapper (props) {
    /*-----------------------------------------------------------------
        - Wrapper for file upload box
        - has three different stages:
            - Default: prompts user to select a file or a link
            - Choosing Link: displayed when the user selects "ENVIAR LINK"; renders "ChooseLinkSection.js"
            - file selected: displayed when the user has chosen a file to upload. this section shows the upload progress and lets the user delete the current object and return to default stage
            - error: displayed when an error occurs during the file upload.

        - Props used:
            - submit : called when the user clicks "ENVIAR" inside ChooseLinkSection; renders the alert snackbar to let them know the link was submitted
    */

    const [stage, setStage] = useState(props.prevFile ? "fileSelected" : "default")
    const handleNextStage = (newStage) => {setStage(newStage)}

    const [fileToUpload, setFileToUpload] = useState(null);
    const chunkSize = 262144
    const uploadUrl = `${apiUrl}/learning_objects/` + props.draftID + '/chunk'
    const [fileName, setFileName] = useState(props.prevFile ? props.prevFile.name : null)
    const [fileDoneUploading, setFileDoneUploading] = useState(props.prevFile ? true : false)
    const [uploadProgress, setProgress] = useState(0)
    const [attachmentID, setAttachmentID] = useState(props.prevFile ? props.prevFile.id : null)

    async function onFileChange (file) {
        if(!file) return;

        let newFile = file
        console.log(newFile)
        setFileToUpload(newFile);
        setFileName(newFile.name)

        let total = Math.ceil(newFile.size/chunkSize)
        let currentChunkStartByte = 0;
        let currentChunkFinalByte = chunkSize > newFile.size ? newFile.size : chunkSize;
        let chunkIdentifier = props.draftID + '-' + newFile.name;
        let remainingBytes = 0
        handleNextStage("fileSelected")
        for (var i = 0; i < total; i++) {
            let chunk = newFile.slice(currentChunkStartByte, currentChunkFinalByte)
            let config = getAxiosConfig()
            let formData = new FormData()
            formData.append('_chunkFilename', newFile.name);
            formData.append('_chunkIdentifier', chunkIdentifier);
            formData.append('_totalChunks', total);
            formData.append('_chunkSize', chunkSize);
            formData.append('_currentChunkSize', chunk.size);
            formData.append('_chunkNumber', i);
            formData.append('_totalSize', newFile.size);
            formData.append('file', chunk);

            try {
                const response = await axios.post(uploadUrl, formData, config);
                console.log(response)
                if (response.headers['access-token']) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                setProgress(Math.round((currentChunkFinalByte/newFile.size) * 100))
                remainingBytes = newFile.size - currentChunkFinalByte;
                if (currentChunkFinalByte === newFile.size) {
                    setFileDoneUploading(true)
                    setAttachmentID(response.data.id)
                }
                else if (remainingBytes < chunkSize) {
                    currentChunkStartByte = currentChunkFinalByte;
                    currentChunkFinalByte = currentChunkStartByte + remainingBytes;
                }
                else {
                    currentChunkStartByte = currentChunkFinalByte;
                    currentChunkFinalByte = currentChunkStartByte + chunkSize;
                }
            } catch (error) {
                console.log(error)
                handleNextStage("error")
                return;
            }
        }
    };

    const handleDelete = () => {
        if (attachmentID != null) {

        let config = getAxiosConfig()
        axios.delete( (`${apiUrl}/learning_objects/` + props.draftID + '/attachment/' + attachmentID), config).then(
            (response) => {
                console.log(response)
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                handleNextStage("default")
            },
            (error) => {console.log(error)})
        }
    }

    const handleCancel = () => {
        console.log('cancelar request')
    }

    const handleDragOver = e => {
        e.preventDefault();
        e.stopPropagation();
        e.dataTransfer.dropEffect = 'copy';
    };

    const handleDrop = e => {
        e.preventDefault();
        e.stopPropagation();
        let files = [...e.dataTransfer.files]

        console.log('files: ', files)
        if (files && files.length > 0) {
            onFileChange(files[0])
        }
    };

    const [snackbarOpen, toggleSnackbar] = useState(false)
    const handleChooseLink = (link) => {
        let config = getAxiosConfig()
        let payload = {
            "learning_object" : {
                "id" : props.draftID,
                "link" : link
            }
        }
        axios.put((`${apiUrl}/learning_objects/` + props.draftID), payload, config).then(
            (response) => {
                console.log(response)
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                toggleSnackbar(true)
            }, (error) => {
                console.log(error)
            }
        )

    }

    switch (stage) {
        case "error":
            return(
                <WrapperBox>
                    <div className="inner">
                        <div className="upload-title">Erro</div>
                            <span>Clique no botão para tentar novamente.</span>
                        <div className="flex-column">
                            <div className="buttons-div">
                                <GrayButton onClick={() => {handleNextStage("default")}}>
                                    <span className="button-text">
                                        Voltar
                                    </span>
                                </GrayButton>
                            </div>
                        </div>
                    </div>
                </WrapperBox>
            )
            break;
        case "fileSelected":
            return(
                <WrapperBox>
                    <div className="inner">
                        <div className="upload-title">
                            {fileDoneUploading ? 'O arquivo foi carregado' : 'Carregando arquivo'}
                        </div>

                        <div className="uploading">
                            <div className="upload-item">
                                <div className="item-info">
                                    {
                                        fileDoneUploading ?
                                        (
                                            <React.Fragment>
                                                <div className="file-status">
                                                    <DoneIcon className="icon icon-margin"/> {fileName}
                                                    </div>
                                                    <GrayButton onClick={() => {handleDelete()}}>
                                                        Excluir <DeleteIcon className="icon icon-remove"/>
                                                    </GrayButton>
                                            </React.Fragment>
                                        )
                                        :
                                        (
                                            <React.Fragment>
                                            <div className="file-status">
                                                {uploadProgress}% {fileName}
                                            </div>
                                            <GrayButton onClick={() => {handleCancel()}}>
                                                Cancelar <DeleteIcon className="icon icon-remove"/>
                                            </GrayButton>
                                            </React.Fragment>
                                        )
                                    }
                                </div>
                            </div>
                            <div className="warning">
                                <span>Não se esqueça de preencher as</span>
                                <br/>
                                <span>informações sobre o recurso ao lado.</span>
                            </div>
                        </div>
                    </div>
                </WrapperBox>
            )
            break;
        case "choosingLink":
            return (
                <React.Fragment>
                    <Snackbar open={snackbarOpen} autoHideDuration={1000} onClose={() => {toggleSnackbar(false)}}
                        anchorOrigin = {{ vertical:'top', horizontal:'right' }}
                        >
                        <Alert severity="info" style={{backgroundColor:"#00acc1"}}>
                            Link salvo com sucesso!
                        </Alert>
                    </Snackbar>
                    <ChooseLink handleNextStage={handleNextStage} submit={handleChooseLink}/>
                </React.Fragment>
            )
            break;
        default:
            return(
                <WrapperBox>
                    <div className="inner">
                        <div className="upload-title"> Enviar Recurso</div>
                        <div className="flex-column">

                            <div className="upload-container">
                                <div className="upload-form">
                                    <form id="file_upload">
                                        <DottedBox
                                            onDrop={e => handleDrop(e)}
                                            onDragOver={e => handleDragOver(e)}
                                            >
                                            <AddAPhotoIcon className="icon"/>
                                            <input
                                                type="file"
                                                onChange = {(e) => {onFileChange(e.target.files[0])}}
                                                id="upload-file"
                                                style={{display : "none"}}
                                                />
                                            <BlueButton>
                                                <label htmlFor="upload-file" style={{width : "inherit", cursor : "pointer"}}>
                                                    ESCOLHER IMAGEM
                                                </label>
                                            </BlueButton>
                                            <span style={{marginTop : "6px"}}>Ou arrastar e soltar o arquivo aqui</span>
                                        </DottedBox>
                                    </form>
                                </div>
                            </div>

                            <div className="strike-box">
                                <div className="strike"/><h3>ou</h3><div className="strike"/>
                            </div>

                            <div className="enviar-link-texto">
                                <img src={LinkIcon}/>
                                <br/>
                                <span>Enviar link de um recurso de outro site</span>
                            </div>

                            <BlueButton onClick={ () => {handleNextStage("choosingLink")} }>ENVIAR LINK</BlueButton>
                        </div>
                    </div>
                </WrapperBox>
            )
    }

}
