/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useEffect, useState, useContext} from 'react'
import {Store} from '../Store.js'
import styled from 'styled-components'
import axios from 'axios'
import {apiUrl, apiDomain} from '../env';
import Grid from '@material-ui/core/Grid';
import TextoObjeto from '../Components/ResourcePageComponents/TextoObjeto.js'
import Footer from '../Components/ResourcePageComponents/Footer.js'
import Sobre from '../Components/ResourcePageComponents/Sobre.js'
import CommentsArea from '../Components/ResourcePageComponents/CommentsArea.js'
import noAvatar from "../img/default_profile.png";
import Snackbar from '@material-ui/core/Snackbar';
import Alert from '../Components/Alert.js';
import VideoPlayer from '../Components/ResourcePageComponents/VideoPlayer.js'
import LoadingSpinner from '../Components/LoadingSpinner.js'
import { makeStyles } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import ButtonAvaliarRecurso from '../Components/ButtonAvaliarRecurso'
import ModalAvaliarRecurso from '../Components/ModalAvaliarRecurso'
import ModalConfirmarCuradoria from '../Components/ModalConfirmarCuradoria'
import {getAxiosConfig} from '../Components/HelperFunctions/getAxiosConfig'

function urlVerify (url) {
    return (url ? url.indexOf("youtu") !== -1 || url.indexOf("vimeo") !== -1 : false)
}

export default function LearningObjectPage (props){
    const {state} = useContext(Store)
    const id = props.match.params.recursoId
    const [carregando, toggle] = useState(true)
    const [recurso, setRecurso] = useState({})

    useEffect( () => {
        let config = {
            headers : {
                'Accept': 'application/json',
                'Content-Type': 'application/json',
            }
        }
        if (state.currentUser.id !== "") {
            config.headers["Access-Token"] = sessionStorage.getItem('@portalmec/accessToken');
            config.headers.Client = sessionStorage.getItem('@portalmec/clientToken')
            config.headers.Uid = sessionStorage.getItem('@portalmec/uid')
        }

        axios.get( (`${apiUrl}/learning_objects/` + id), config
        ).then( (response) => {
            if ( response.headers['access-token'] ) {
                sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
            }
            console.log(response)
            setRecurso(response.data)
            toggle(false)
        }, (error) => {console.log(error);})
    }, [, state.currentUser])


    const [snackbarOpen, toggleSnackbar] = useState(false)
    const handleSnackbar = (index) => {setIndex(index); toggleSnackbar(true)}
    const snackbarText = [
        "Baixando o Recurso... Lembre-se de relatar sua experiência após o uso do Recurso!",
        "Seu comentário foi publicado com sucesso!",
        "Comentário editado com sucesso.",
        "Comentário deletado com sucesso.",
        "O Recurso foi guardado na coleção!"
    ]
    const [snackbarIndex, setIndex] = useState(0)
    const classes = useStyles()
    const [modalCuradoriaOpen, toggleModalCuradoria] = useState(false)
    const handleModalCuradoria = (value) => {toggleModalCuradoria(value)}

    const checkAccessLevel = (levelToCheck) => {
        if (state.currentUser.id != '') {
            return(checkUserRole(levelToCheck))
        }
        else {
            return(false)
        }
    }

    const checkUserRole = (userRole) => {
        return(state.currentUser.roles.filter((role) => role.name === userRole).length > 0)
    }

    const [modalConfirmarCuradoriaOpen, toggleModalConfirmarCuradoria] = useState(false)
    const handleModalConfirmarCuradoria = (value) => {toggleModalConfirmarCuradoria(value)}
    const [reportCriteria, setReportCriteria] = useState([])
    const [justificativa, setJustificativa] = useState('')
    const [submissionAccepted, setSubmissionAccepted] = useState('')

    const handleConfirm = (criteria, justification, accepted) => {
        console.log('criteria: ', criteria)
        console.log('justification: ', justification)
        setReportCriteria(criteria)
        setJustificativa(justification)
        setSubmissionAccepted(accepted)
        handleModalCuradoria(false)
        handleModalConfirmarCuradoria(true)
    }

    const finalizeCuratorshipFlow = () => {
        handleModalConfirmarCuradoria(false)
        let config = getAxiosConfig()
        axios.get( (`${apiUrl}/learning_objects/` + id), config
        ).then( (response) => {
            if ( response.headers['access-token'] ) {
                sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
            }
            console.log(response)
            setRecurso(response.data)
        }, (error) => {console.log(error);})
    }

    return (
        <React.Fragment>
        <Snackbar open={snackbarOpen} autoHideDuration={1000} onClose={toggleSnackbar}
        anchorOrigin = {{ vertical:'top', horizontal:'right' }}
        >
            <Alert severity="info" style={{backgroundColor:"#00acc1"}}>
                {snackbarText[snackbarIndex]}
            </Alert>
        </Snackbar>

        <ModalAvaliarRecurso open={modalCuradoriaOpen} handleClose={() => {handleModalCuradoria(false)}}
            title={recurso.name} confirm={handleConfirm} setCriteria={setReportCriteria}
            />
        <ModalConfirmarCuradoria aceito={submissionAccepted} reportCriteria={reportCriteria} justificativa={justificativa} open={modalConfirmarCuradoriaOpen} handleClose={() => {handleModalConfirmarCuradoria(false)}} cancel={() => {handleModalCuradoria(true)}} recursoId={id}
            finalizeCuratorshipFlow={finalizeCuratorshipFlow}
            />
        <Background>
            {
                carregando ?
                (
                    <LoadingSpinner text={"Carregando Recurso"}/>
                )
                :
                (
                    <>
                        <Grid container spacing={2}>
                            {
                                recurso.object_type === "Vídeo" &&
                                !recurso.link ?
                                (
                                    <Grid item xs={12}><Card>
                                        <VideoPlayer
                                            link={recurso.link}
                                            urlVerified={false}
                                            videoUrl = {recurso.default_attachment_location}
                                            />
                                    </Card></Grid>

                                )
                                :
                                (
                                    urlVerify(recurso.link) &&
                                    <Grid item xs={12}><Card>
                                    <VideoPlayer
                                        link={recurso.link}
                                        urlVerified={true}
                                    />
                                    </Card></Grid>
                                )
                            }


                            <Grid item xs={12}>
                                <Card>
                                    <div>
                                    {recurso.thumbnail &&
                                        <img src={apiDomain + recurso.thumbnail}/>
                                    }




                                    <TextoObjeto
                                        name={recurso.name}
                                        rating={recurso.review_average}
                                        recursoId={id}
                                        likesCount={recurso.likes_count}
                                        likedBool={recurso.liked}
                                        objType={recurso.object_type}
                                        subjects={recurso.subjects}
                                        educationalStages={recurso.educational_stages}
                                        viewCount={recurso.views_count}
                                        downloadCount={recurso.downloads_count}
                                        id={recurso.publisher ? recurso.publisher.id : undefined}
                                        stateRecurso={recurso.state}
                                        attachments={recurso.attachments}
                                        audioUrl={recurso.default_attachment_location}
                                        />
                                    </div>


                                    <Footer
                                        recursoId={id}
                                        downloadableLink = {recurso.default_attachment_location}
                                        handleSnackbar={handleSnackbar}
                                        link={recurso.link}
                                        title={recurso.name}
                                        thumb={recurso.thumbnail}
                                        currPageLink={window.location.href}
                                        handleSnackbar={handleSnackbar}
                                        complained={recurso.complained}
                                        />
                                </Card>
                            </Grid>

                            <Grid item xs={12}>
                                <Card>
                                    {/*todo: change render method on additional item info*/}
                                    <Sobre
                                        avatar={recurso.publisher ? (recurso.publisher.avatar ? (apiDomain + recurso.publisher.avatar) : noAvatar) : noAvatar}
                                        publisher={recurso.publisher ? recurso.publisher.name : undefined}
                                        id={recurso.publisher ? recurso.publisher.id : undefined}
                                        description={recurso.description}
                                        author={recurso.author}
                                        tags={recurso.tags}
                                        attachments={recurso.attachments}
                                        language={recurso.language}
                                        mimeType={recurso.default_mime_type}
                                        createdAt={recurso.created_at}
                                        updatedAt={recurso.updated_at}
                                        license={recurso.license}
                                        />
                                </Card>
                            </Grid>

                            {
                                recurso.state !== "submitted" &&
                                <Grid item xs={12}>
                                    <Card>
                                        {/*adicionar funcionalidade ao botao de entrar*/}
                                        <CommentsArea
                                            recursoId = {id}
                                            handleSnackbar={handleSnackbar}
                                            objType={recurso.object_type}
                                            recurso={true}
                                            />
                                    </Card>
                                </Grid>
                            }
                        </Grid>

                        {
                            recurso.state === 'submitted' && checkAccessLevel('curator') &&
                            <AppBar position="fixed" color="primary" className={classes.appBar}>
                                <StyledAppBarContainer>
                                    <div className="container">
                                        <div className="botoes">
                                            <ButtonAvaliarRecurso callback={() => {handleModalCuradoria(true)}}/>
                                        </div>
                                    </div>
                                </StyledAppBarContainer>
                            </AppBar>
                        }
                        </>
                )
            }

        </Background>
        </React.Fragment>
    )
}

const useStyles = makeStyles((theme) => ({
  appBar: {
    top: 'auto',
    bottom: 0,
    height : '100px',
    backgroundColor : '#fff',
    boxShadow : '0 1px 3px rgba(0,0,0,.52),0 1px 2px rgba(0,0,0,.24)'
  },
}));

const StyledAppBarContainer = styled.div`
    .container {
        display : flex;
        flex-direction : row;
        justify-content : flex-start
        margin-right : auto;
        margin-left : auto;
        @media screen and (min-width: 1200px) {
            width : 1170px;
        }
        @media screen and (min-width: 992px) and (max-width : 1199px){
            width : 970px;
        }
        @media screen and (min-width: 768px) and (max-width : 991px) {
            width : 750px;
        }

        .botoes {
            margin-top : 2em;
            display : flex;
            align-items : center;
        }
    }
`

const Background = styled.div`
    background-color : #f4f4f4;
    color : #666;
    font-family : 'Roboto', sans serif;
    padding-top : 30px;
`

const Card = styled.div`
    background-color : #fff;
    box-shadow : 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    margin-bottom : 30px;
    margin-right : auto;
    margin-left : auto;
    display : flex;
    flex-direction : column;
    @media screen and (min-width: 1200px) {
        width : 1170px;
    }
    @media screen and (min-width: 992px) and (max-width : 1199px){
        width : 970px;
    }
    @media screen and (min-width: 768px) and (max-width : 991px) {
        width : 750px;
    }

    img {
        background-color : #e5e5e5;
        height : 270px;
        width : 400px;
        float : left;
        padding : 0;
        object-fit : cover;
        @media screen and (max-width: 768px) {
            height : auto;
            width : 100%;
        }
    }
`
