/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect, useContext} from 'react'
import axios from 'axios'
import {apiUrl, apiDomain} from '../env';
import Grid from '@material-ui/core/Grid';
import UploadFileWrapper from '../Components/UploadPageComponents/UploadFileWrapper.js'
import {Store} from '../Store.js'
import {InfoBox} from '../Components/UploadPageComponents/StyledComponents.js'
import Stepper from '../Components/UploadPageComponents/Stepper.js'
import {getAxiosConfig} from '../Components/HelperFunctions/getAxiosConfig.js'
import PartOne from '../Components/UploadPageComponents/PartOne.js'
import PartTwo from '../Components/UploadPageComponents/PartTwo.js'
import PartThree from '../Components/UploadPageComponents/PartThree.js'
import ModalLearningObjectPublished from '../Components/ModalLearningObjectPublished.js'
import {Background} from '../Components/UploadPageComponents/StyledComponents'
import LoadingSpinner from '../Components/LoadingSpinner.js'
import {Redirect} from 'react-router-dom'

export default function UploadPage (props) {
    const {state} = useContext(Store)

    {/*Object : link or file uploaded*/}
    const [object, setObject] = useState()

    const [loading, toggleLoading] = useState(true)
    const [draft, setDraft] = useState({})
    useEffect( () => {
        if (state.currentUser.id !== "") {
            const config = getAxiosConfig()
            let payload = {}
            axios.post( (`${apiUrl}/learning_objects/`), payload, config
            ).then( (response) => {
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                setDraft(response.data)
                toggleLoading(false)
                console.log(response)
            }, (error) => {console.log(error)})
        }
    }, [])

    const [activeStep, setActiveStep] = React.useState(0);
    const stepperControl=(increment)=>{setActiveStep(activeStep + increment)}

    const [objectSubmitted, toggleModal] = useState(false)
    const handleModal = (value) => {toggleModal(value)}

    const handlePost = () => {
        if (state.currentUser.id !== "") {
            const config = getAxiosConfig()
            let payload = {}
            axios.post( (`${apiUrl}/learning_objects/` + draft.id + '/publish'), payload, config
            ).then( (response) => {
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                handleModal(true)
                console.log(response)

            }, (error) => {console.log(error)})
        }
    }

    const handleSubmit = () => {
        if (state.currentUser.id !== "") {
            const config = getAxiosConfig()
            let payload = {
                "submission" : {
                    "learning_object_id" : draft.id
                }
            }

            axios.post( (`${apiUrl}/submissions/`), payload, config
            ).then( (response) => {
                if ( response.headers['access-token'] ) {
                    sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
                }
                handleModal(true)
                console.log(response)

            }, (error) => {console.log(error)})
        }
    }

    return (
        <React.Fragment>
            {
                state.currentUser.id === '' &&
                <Redirect to="/"/>
            }
            {
                loading === true ?
                (
                    <LoadingSpinner text={"CARREGANDO..."}/>
                )
                :
                (
                    <>
                    <ModalLearningObjectPublished
                        open={objectSubmitted}
                        handleClose={() => {toggleModal(false); props.history.push('/')}}
                        draftID={draft.id}
                        />
                    {
                        activeStep === 2 ?
                        (
                            <PartThree draftID={draft.id} stepperControl={stepperControl} activeStep={activeStep} handlePost={handlePost} handleSubmit={handleSubmit}/>
                        )
                        :
                        (
                            <Background>
                                <div className="container">
                                    <Grid container spacing={2}>
                                        <Grid item md={4} xs={12}>
                                            <UploadFileWrapper draftID={draft.id}/>
                                        </Grid>
                                        <Grid item md={8} xs={12}>
                                            <InfoBox>
                                                <div className="cabecalho">
                                                    <h2>Informações sobre o Recurso</h2>
                                                    <div className="feedback-upload">
                                                        <Stepper activeStep={activeStep}/>
                                                    </div>
                                                </div>
                                                {
                                                    activeStep === 0 &&
                                                    <Grid container style={{paddingLeft : "15px", paddingRight : "15px"}}>
                                                        <PartOne draftID={draft.id} stepperControl={stepperControl}/>
                                                    </Grid>
                                                }
                                                {
                                                    activeStep === 1 &&
                                                    <Grid container style={{paddingLeft : "15px", paddingRight : "15px"}}>
                                                        <PartTwo draftID={draft.id} stepperControl={stepperControl}/>
                                                    </Grid>
                                                }
                                            </InfoBox>
                                        </Grid>
                                    </Grid>
                                </div>
                            </Background>
                        )
                    }
                    </>
                )
    }
    </React.Fragment>
)
}
